wasm_tokenize_spell_desc

Function wasm_tokenize_spell_desc 

pub fn wasm_tokenize_spell_desc(input: &str) -> Result<JsValue, WasmCommonError>
Tokenize a spell description into fragments for debug display.

Errors

Returns WasmCommonError when the token fragments cannot be serialized for JavaScript.